"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spread = (this && this.__spread) || function () {
    for (var ar = [], i = 0; i < arguments.length; i++) ar = ar.concat(__read(arguments[i]));
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTextIndices = void 0;
var defaultOptions = { caseSensitive: true };
function stringEquals(str1, str2, caseSensitive) {
    return ((caseSensitive ? str1 : str1.toLowerCase()) ===
        (caseSensitive ? str2 : str2.toLowerCase()));
}
/**
 * Finds the indices of the 'searchText' in the 'fullStr'
 * @param {string} fullStr The string to search on
 * @param {string} searchText The string to find indices in the 'fullStr'
 * @param {boolean} multiple If this is set to true then the function will return an array of matches
 * @param {GetTextIndicesOptions} options The options
 */
function getTextIndices(fullStr, searchText, multiple, options) {
    if (multiple === void 0) { multiple = false; }
    if (options === void 0) { options = defaultOptions; }
    if (typeof fullStr !== 'string')
        throw new Error("'fullStr' must be string");
    else if (typeof searchText !== 'string')
        throw new Error("'searchText' must be a string");
    else if (typeof multiple !== 'boolean')
        throw new Error("'multiple' must be a boolean");
    var caseSensitive = options.caseSensitive;
    var regex = new RegExp(searchText, "g" + (caseSensitive ? '' : 'i'));
    var searchResults = __spread(fullStr.matchAll(regex));
    var results = [];
    if (!searchResults)
        return results;
    searchResults.forEach(function (result) {
        var startIndex = result.index;
        if (typeof startIndex !== 'number')
            return;
        var foundedText = '';
        for (var i = startIndex; i < fullStr.length; i++) {
            foundedText += fullStr[i];
            if (stringEquals(foundedText, searchText, caseSensitive))
                results.push({ start: startIndex, end: i });
        }
    });
    return results;
}
exports.getTextIndices = getTextIndices;
